@@ -2,9 +2,6 @@
 context('Row and column functions, set_* interface')
 
 
-source('functions.R')
-
-
 test_that('Row/column function examples unchanged', {
   test_ex_same('every')
   test_ex_same('final')
@@ -157,7 +154,8 @@ test_that('all forms of set_all_* work as expected', {
   border_size <- 2
   ht6 <- set_all_borders(ht, border_size)
   expect_equivalent(top_border(ht6), matrix(border_size, 2, 2))
-  ht7 <- set_all_borders(ht, 1:2, dplyr::matches('a|b'), 1)
+
+  ht7 <- set_all_borders(ht, 1:2, tidyselect::matches('a|b'), 1)
   expect_equivalent(top_border(ht7), matrix(1, 2, 2))
 })
 
@@ -193,7 +191,7 @@ test_that('set_outer_borders() works as expected', {
   check_borders(ht3)
   ht4 <- set_outer_borders(ht, 2:3, c("b", "c"), 1)
   check_borders(ht4)
-  ht5 <- set_outer_borders(ht, 2:3, dplyr::matches('b|c'), 1) # testthat has a `matches` function
+  ht5 <- set_outer_borders(ht, 2:3, tidyselect::matches('b|c'), 1) # testthat has a `matches` function
   check_borders(ht5)
 })
 
