@@ -2,9 +2,6 @@
 context('Test output using pandoc')
 
 
-source('functions.R')
-
-
 test_that('Four spaces does not cause <pre><code> markup', {
   skip_without_pandoc()
   skip_on_cran()
@@ -27,7 +24,8 @@ test_that('Row heights do not screw up LaTeX multicol', {
 test_that('table-tester-2.Rmd renders without errors in LaTeX', {
   skip_without_pandoc()
   skip_on_cran()
-  skip_on_travis() # temporary
+  skip_if_not_installed('broom') # for huxreg
+
   on.exit(if (exists('output')) file.remove(output))
   expect_silent(output <- rmarkdown::render('table-tester-2.Rmd', quiet = TRUE, output_format = "pdf_document"))
 })
@@ -36,6 +34,8 @@ test_that('table-tester-2.Rmd renders without errors in LaTeX', {
 test_that('table-tester-2.Rmd renders without errors in HTML', {
   skip_without_pandoc()
   skip_on_cran()
+  skip_if_not_installed('broom') # for huxreg
+
   on.exit(if (exists('output')) file.remove(output))
   expect_silent(output <- rmarkdown::render('table-tester-2.Rmd', quiet = TRUE, output_format = "html_document"))
 })
